@@ -10,7 +10,7 @@ import requests
 from flask import Flask, jsonify, make_response, render_template, request, url_for
 
 from .conf import config
-from .decorators import process_token
+from .decorators import handle_source_site_errors, process_token
 from .persistence import (
     create_token,
     delete_token,
@@ -80,6 +80,11 @@ def _is_manga_img_url(
     return pattern.match(url)
 
 
+def proxied(url) -> str:
+    path = url_for("proxy_view", b64_url=_encode_proxy_url(url))
+    return config.PROXY_PREFIX + path
+
+
 @app.route("/proxy/<b64_url>")
 def proxy_view(b64_url):
     """
@@ -201,14 +206,13 @@ def _title(site, title_id, user_id=None):
         print("Loading title", title_id, "from db")
     title["cover"] = title_cover(site, title_id, title["cover_ext"])
     if site == "mangadex":
-        title["cover"] = url_for(
-            "proxy_view", b64_url=_encode_proxy_url(title["cover"])
-        )
+        title["cover"] = proxied(title["cover"])
     title["source_url"] = title_source_url(site, title_id)
     return title
 
 
 @app.route("/m/<site>/<title_id>")
+@handle_source_site_errors("html")
 def spa_title_view(site, title_id):
     title = _title(site, title_id)
     return render_template(
@@ -222,6 +226,7 @@ def spa_title_view(site, title_id):
 
 
 @app.route("/m/<site>/<title_id>/<chapter_id>")
+@handle_source_site_errors("html")
 def spa_chapter_view(site, title_id, chapter_id):
     chapter = load_chapter(site, title_id, chapter_id)
     if not chapter:
@@ -235,9 +240,7 @@ def spa_chapter_view(site, title_id, chapter_id):
     title = load_title(site, title_id)
     title["cover"] = title_cover(site, title_id, title["cover_ext"])
     if site == "mangadex":
-        title["cover"] = url_for(
-            "proxy_view", b64_url=_encode_proxy_url(title["cover"])
-        )
+        title["cover"] = proxied(title["cover"])
 
     chapter["site"] = site
     return render_template(
@@ -252,6 +255,7 @@ def spa_chapter_view(site, title_id, chapter_id):
 
 @app.route("/api/title/<site>/<title_id>", methods=["GET"])
 @process_token(required=False)
+@handle_source_site_errors("json")
 def api_title(site, title_id):
     title = _title(site, title_id, user_id=request.user_id)
     return title
@@ -259,6 +263,7 @@ def api_title(site, title_id):
 
 @app.route("/api/chapter/<site>/<title_id>/<chapter_id>", methods=["GET"])
 @process_token(required=False)
+@handle_source_site_errors("json")
 def api_chapter(site, title_id, chapter_id):
     chapter = load_chapter(site, title_id, chapter_id)
     if not chapter:
@@ -269,18 +274,13 @@ def api_chapter(site, title_id, chapter_id):
         print("Loading chapter", chapter_id, "from db")
 
     if site in ("mangadex", "mangasee"):
-        chapter["pages"] = [
-            url_for("proxy_view", b64_url=_encode_proxy_url(p))
-            for p in chapter["pages"]
-        ]
+        chapter["pages"] = [proxied(p) for p in chapter["pages"]]
 
     # YIIIIKES
     title = load_title(site, title_id)
     title["cover"] = title_cover(site, title_id, title["cover_ext"])
     if site == "mangadex":
-        title["cover"] = url_for(
-            "proxy_view", b64_url=_encode_proxy_url(title["cover"])
-        )
+        title["cover"] = proxied(title["cover"])
     prev_chapter, next_chapter = get_prev_next_chapters(title, chapter)
     chapter["prev_chapter"] = prev_chapter
     chapter["next_chapter"] = next_chapter
@@ -363,7 +363,7 @@ def api_follows():
     for title in titles:
         thumbnail = title_thumbnail(title["site"], title["id"])
         if title["site"] == "mangadex":
-            thumbnail = url_for("proxy_view", b64_url=_encode_proxy_url(thumbnail))
+            thumbnail = proxied(thumbnail)
         title["thumbnail"] = thumbnail
     return jsonify({"titles": titles})
 
@@ -374,14 +374,13 @@ def api_search(query):
 
     if "mangadex" in results:
         for title in results["mangadex"]:
-            title["thumbnail"] = url_for(
-                "proxy_view", b64_url=_encode_proxy_url(title["thumbnail"])
-            )
+            title["thumbnail"] = proxied(title["thumbnail"])
     return results
 
 
 @app.route("/api/follow", methods=["POST"])
 @process_token(required=True)
+@handle_source_site_errors("json")
 def api_follow():
     should_follow = request.json["follow"]
     site = request.json["site"]
@@ -405,12 +404,18 @@ def api_read():
     if reads:
         for r in reads:
             read(
-                request.user_id, r["site"], r["title_id"], r["chapter_id"],
+                request.user_id,
+                r["site"],
+                r["title_id"],
+                r["chapter_id"],
             )
     if unreads:
         for u in unreads:
             unread(
-                request.user_id, u["site"], u["title_id"], u["chapter_id"],
+                request.user_id,
+                u["site"],
+                u["title_id"],
+                u["chapter_id"],
             )
     # TODO: rewrite read/unread to do bulk updates instead of n+1 queries like these.
     # ... Or maybe not. SQLite doesn't mind.
@@ -422,6 +427,7 @@ def api_read():
 
 @app.route("/api/import", methods=["POST"])
 @process_token(required=True)
+@handle_source_site_errors("json")
 def api_import():
     # check if the post request has the file part
     if "tachiyomi" not in request.files:
